@@ -91,6 +91,15 @@ namespace strumpack {
     return ReturnCode::SUCCESS;
   }
 
+  template<typename scalar_t,typename integer_t> ReturnCode
+  FrontalMatrixDense<scalar_t,integer_t>::node_pivot_growth
+  (scalar_t& pgL, scalar_t& pgU) const {
+    for (std::size_t i=0; i<F11_.rows(); i++)
+      pgU = std::max(std::abs(pgU), std::abs(F11_(i, i)));
+    pgL = std::max(std::abs(pgL), std::abs(scalar_t(1.)));
+    return ReturnCode::SUCCESS;
+  }
+
   template<typename scalar_t,typename integer_t> void
   FrontalMatrixDense<scalar_t,integer_t>::extend_add_to_dense
   (DenseM_t& paF11, DenseM_t& paF12, DenseM_t& paF21, DenseM_t& paF22,
